@@ -17,7 +17,6 @@
 package org.apache.tomcat.util.http;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
@@ -28,7 +27,6 @@ import java.util.Map;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.buf.B2CConverter;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.buf.MessageBytes;
 import org.apache.tomcat.util.buf.StringUtils;
@@ -78,30 +76,10 @@ public final class Parameters {
         this.limit = limit;
     }
 
-    /**
-     * @return The current encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public String getEncoding() {
-        return charset.name();
-    }
-
     public Charset getCharset() {
         return charset;
     }
 
-    /**
-     * @param s The new encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public void setEncoding(String s) {
-        setCharset(getCharset(s, DEFAULT_BODY_CHARSET));
-    }
-
     public void setCharset(Charset charset) {
         if (charset == null) {
             charset = DEFAULT_BODY_CHARSET;
@@ -112,16 +90,6 @@ public final class Parameters {
         }
     }
 
-    /**
-     * @param s The new query string encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9
-     */
-    @Deprecated
-    public void setQueryStringEncoding(String s) {
-        setQueryStringCharset(getCharset(s, DEFAULT_URI_CHARSET));
-    }
-
     public void setQueryStringCharset(Charset queryStringCharset) {
         if (queryStringCharset == null) {
             queryStringCharset = DEFAULT_URI_CHARSET;
@@ -221,7 +189,7 @@ public final class Parameters {
             decodedQuery.duplicate(queryMB);
         } catch (IOException e) {
             // Can't happen, as decodedQuery can't overflow
-            log.error(sm.getString("parameters.copyFail"), e);
+            e.printStackTrace();
         }
         processParameters(decodedQuery, queryStringCharset);
     }
@@ -241,12 +209,7 @@ public final class Parameters {
         }
         parameterCount++;
 
-        ArrayList<String> values = paramHashValues.get(key);
-        if (values == null) {
-            values = new ArrayList<>(1);
-            paramHashValues.put(key, values);
-        }
-        values.add(value);
+        paramHashValues.computeIfAbsent(key, k -> new ArrayList<>(1)).add(value);
     }
 
     public void setURLDecoder(UDecoder u) {
@@ -260,11 +223,6 @@ public final class Parameters {
     private final ByteChunk tmpValue = new ByteChunk();
     private final ByteChunk origName = new ByteChunk();
     private final ByteChunk origValue = new ByteChunk();
-    /**
-     * @deprecated This will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public static final String DEFAULT_ENCODING = "ISO-8859-1";
     private static final Charset DEFAULT_BODY_CHARSET = StandardCharsets.ISO_8859_1;
     private static final Charset DEFAULT_URI_CHARSET = StandardCharsets.UTF_8;
 
@@ -511,17 +469,6 @@ public final class Parameters {
         urlDec.convert(bc, true);
     }
 
-    /**
-     * @param data     Parameter data
-     * @param encoding Encoding to use for encoded bytes
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public void processParameters(MessageBytes data, String encoding) {
-        processParameters(data, getCharset(encoding, DEFAULT_BODY_CHARSET));
-    }
-
     public void processParameters(MessageBytes data, Charset charset) {
         if (data == null || data.isNull() || data.getLength() <= 0) {
             return;
@@ -534,17 +481,6 @@ public final class Parameters {
         processParameters(bc.getBytes(), bc.getOffset(), bc.getLength(), charset);
     }
 
-    private Charset getCharset(String encoding, Charset defaultCharset) {
-        if (encoding == null) {
-            return defaultCharset;
-        }
-        try {
-            return B2CConverter.getCharset(encoding);
-        } catch (UnsupportedEncodingException e) {
-            return defaultCharset;
-        }
-    }
-
     /**
      * Debug purpose
      */
